# oc-mirror

## Overview

A utility that can be used to mirror OpenShift releases between docker registries.

## Compatibility

* Tested with python 3.8

## Installation
### From [pypi.org](https://pypi.org/project/oc-mirror/)

```
$ pip install oc_mirror
```

### From source code

```bash
$ git clone https://github.com/crashvb/oc-mirror
$ cd oc-mirror
$ virtualenv env
$ source env/bin/activate
$ python -m pip install --editable .[dev]
```

## Usage

TODO

### Environment Variables

None.

## Development

[Source Control](https://github.com/crashvb/oc-mirror)
